@@ -26,13 +26,11 @@
  */
 
 var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
+var timer = require("sdk/timers");
 
 var scriptProperties = require("html_script_finder/dom_handler/script_properties");
-
 const scriptTypes = scriptProperties.scriptTypes;
-
 const statusTypes = scriptProperties.statusTypes;
-
 const reasons = scriptProperties.reasons;
 
 // ensure xhr won't create an infinite loop
@@ -40,19 +38,14 @@ const reasons = scriptProperties.reasons;
 var urlTester = require("html_script_finder/url_seen_tester").urlSeenTester;
 var urlHandler = require("url_handler/url_handler");
 
-
 var privacyChecker = require("js_checker/privacy_checker").privacyCheck;
 var jsChecker = require("js_checker/js_checker");
 
 const types = require("js_checker/constant_types");
-
 var checkTypes = types.checkTypes;
-
 var stripCDATAOpen = /<\!\[CDATA\[/gi;
 var stripCDATAClose = /]]>/g;
 
-var timer = require("sdk/timers");
-
 const getHash = require("script_entries/scripts_cache").scriptsCached.getHash;
 
 var DomChecker = function() {
@@ -154,7 +147,6 @@ DomChecker.prototype.concatAttributes = function(script) {
     }
 
     return text;
-
 };
 
 /**
@@ -247,6 +239,7 @@ DomChecker.prototype.processInlineCheckResult = function(
 DomChecker.prototype.readyForExternal = function() {
     "use strict";
 
+    console.debug('DomChecker.readyForExternal');
     // done with those inline scripts, continue with
     // the rest.
     this.checkExternalScripts();
@@ -260,6 +253,8 @@ DomChecker.prototype.checkSingleInlineScript = function(
     "use strict";
     var check, text;
 
+    console.debug('DomChecker.checkSingleInlineScript');
+
     try {
 
         check = checker.parseTree.freeTrivialCheck;
@@ -288,36 +283,40 @@ DomChecker.prototype.checkSingleInlineScript = function(
  */
 DomChecker.prototype.checkExternalScripts = function() {
     "use strict";
-    var i = 0, 
-        len = this.d.externalScripts.length,
-        that = this;
-    console.debug("externalScripts length", this.d.externalScripts.length);
-    if (this.d.removedAllScripts ||
-            this.d.externalScripts.length === 0) {
-                // all js has already been removed.
-                // stop check.
-                this.wrapUpBeforeLeaving();
-                return;
 
-            }
+    console.debug('DomChecker.checkExternalScripts');
+
+    var i = 0;
+    var len = this.d.externalScripts.length;
+    var that = this;
+
+    console.debug("externalScripts length", len);
+    if (this.d.removedAllScripts || len === 0) {
+        // all js has already been removed.
+        // stop check.
+        this.wrapUpBeforeLeaving();
+        return;
+    }
 
     for (; i < len; i++) {
+        this.xhr(
+            this.d.externalScripts[i],
+            function(script, scriptText) {
+                console.debug("In xhr callback for script url:", script.url);
+                if (scriptText === false) {
+                    that.d.removeGivenJs(script);
+                    that.d.scriptHasBeenTested();
+                    that.externalCheckIsDone();
+                    return;
+                }
 
-        this.xhr(this.d.externalScripts[i], 
-
-                function(script, scriptText) { 
-                    console.debug("doing xhr", script.url);
-                    if (scriptText === false) {
-                        that.d.removeGivenJs(script);
-                        that.d.scriptHasBeenTested();
-                        that.externalCheckIsDone();
-                        return;
-                    }
-
-                    that.analyzeJs(script, 
-                        scriptText, 
-                        that.checkSingleExternalScript.bind(that));
-                });
+                console.debug('about to analyzeJS for script:', script.url);
+                that.analyzeJs(
+                    script,
+                    scriptText,
+                    that.checkSingleExternalScript.bind(that));
+            }
+        );
     }
 };
 
@@ -332,8 +331,8 @@ DomChecker.prototype.wrapUpBeforeLeaving = function() {
 
 DomChecker.prototype.analyzeJs = function(script, scriptText, callback) {
     "use strict";
+    console.debug('DomChecker.analyzeJs for script:', script.url);
     try {
-        console.debug("checking ", script.url);
         var checker = jsChecker.jsChecker();
         var url = "";
         if (typeof script.url !== "undefined") {
@@ -356,17 +355,19 @@ DomChecker.prototype.analyzeJs = function(script, scriptText, callback) {
  * Check a single external script.
  */
 DomChecker.prototype.checkSingleExternalScript = function(
-        script, loadedScript, checker) {
+    script, loadedScript, checker
+) {
     "use strict";
     var check;
 
+    console.debug('DomChecker.checkSingleExternalScript()');
     try {
-
         check = checker.parseTree.freeTrivialCheck;
 
         script.tree = checker;
         script.result = check;
-        console.debug('in checkSingleExternalScript, checker.hash is', checker.hash);
+        console.debug('in checkSingleExternalScript, checker.hash is',
+                      checker.hash);
         if (script.status != statusTypes.JSWEBLABEL) {
             script.status = statusTypes.CHECKED;		
         } 
@@ -391,12 +392,13 @@ DomChecker.prototype.checkSingleExternalScript = function(
         } else {
             // anything else is nontrivial. Including TRIVIAL_DEFINES_FUNCTION.
             console.debug("checker hash for remove is ", checker.hash);
-            this.d.removeGivenJs(script, reasons.FUNCTIONS_EXTERNAL, false, checker.hash);
+            this.d.removeGivenJs(
+                script, reasons.FUNCTIONS_EXTERNAL, false, checker.hash);
         } 
 
     } catch (e) {
         console.debug('error in checkExternalScript',
-                e, e.lineNumber, 'for script', script.url);
+                      e, e.lineNumber, 'for script', script.url);
 
         this.d.removeAllJs();
         this.destroy();
@@ -409,6 +411,7 @@ DomChecker.prototype.checkSingleExternalScript = function(
 
 DomChecker.prototype.externalCheckIsDone = function() {
     "use strict";
+    console.debug('DomChecker.externalCheckIsDone');
 
     console.debug('scriptsTested is', this.d.scriptsTested);
     console.debug('num external', this.d.numExternalScripts);
@@ -416,6 +419,17 @@ DomChecker.prototype.externalCheckIsDone = function() {
     if (this.d.scriptsTested  >= this.d.numExternalScripts) {
         console.debug('wrapping up external');
         this.wrapUpBeforeLeaving();
+    } else {
+        var scriptsToCheck = this.d.numExternalScripts - this.d.scriptsTested;
+        console.debug('Not wrapping up! Waiting to check ' + scriptsToCheck +
+                      ' more script(s)');
+
+        if (this.d.externalScripts[0]) {
+            console.debug('script 0 is', this.d.externalScripts[0]);
+        }
+        if (this.d.externalScripts[1]) {
+            console.debug('script 1 is', this.d.externalScripts[1]);
+        }
     }
 };
 
