@@ -35,7 +35,8 @@ exports.addToCache = function (lic, delay, jsWebLabelsURL, callback) {
         var cb = function (script, contents) {
             try {
                 // add a cache entry.
-                var hash = scriptsCached.addEntryIfNotCached(contents, 
+                var hash = scriptsCached.addEntryIfNotCached(
+                    contents,
                     types.freeWithComment(
                         'This script is free according to a JS Web Labels page visited recently (at ' +
                             jsWebLabelsURL.replace("librejs=true", "") + ' )'),
@@ -53,6 +54,7 @@ exports.addToCache = function (lic, delay, jsWebLabelsURL, callback) {
             cb = function() {};
             callback(lic.fileUrl); }, 20000);
 
-        xhr({'url': lic.fileUrl}, cb);},
-    delay);
+        xhr({'url': lic.fileUrl}, cb);
+    },
+                      delay);
 };
