@@ -41,4 +41,4 @@ exports.testBug = function (assert, done) {
     });
 };
 
-require('sdk/test').run(exports);
+//require('sdk/test').run(exports);
