@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,120 +22,107 @@ const nonTrivialCheckModule = require("js_checker/nontrivial_checker");
 const check = nonTrivialCheckModule.nonTrivialChecker(false, false);
 const mn = require("./mock/mock_nodes");
 var testRunner;
-const remainingTests;
 
 const constants = require("js_checker/constant_types");
 var checkTypes = constants.checkTypes;
 
-var testCheckNontrivial = function (test, n) {
-    test.assertEqual(checkTypes.NONTRIVIAL_GLOBAL, check.checkNontrivial(n));
+var testCheckNontrivial = function (assert, n) {
+    assert.equal(checkTypes.NONTRIVIAL, check.checkNontrivial(n).type);
 };
 
 
-exports.testInvokesEvalIdentifier = function (test) {    
+exports.testInvokesEvalIdentifier = function (assert) {
     // a node that could be found during 
     // jsChecker walkTree execution.
     // n corresponds to "eval".
-    var n = mn.mockNodes['eval'];
+    var n = mn.mockNodes.eval;
     // making sure we have a correct (as expected) tree
-    test.assertEqual(true, check.invokesEval(n));
+    assert.equal(true, check.invokesEval(n));
     //testCheckNontrivial(test, n1);
-    test.done();
 };
 
-exports.testInvokesEvalIdentifier_2 = function (test) {
+exports.testInvokesEvalIdentifier_2 = function(assert) {
     // a node that could be found during 
     // jsChecker walkTree execution.
     // n corresponds to "evaluate"
-    var n = mn.mockNodes['evaluate'];
+    var n = mn.mockNodes.evaluate;
     // making sure we have a correct (as expected) tree
-    test.assertNotEqual(true, check.invokesEval(n));
-    test.done();
+    assert.notEqual(true, check.invokesEval(n));
 };
 
-exports.testInvokesMethodBracketSuffix = function (test) {
+exports.testInvokesMethodBracketSuffix = function(assert) {
     // n corresponds to window['eval']('var i;');
     var n = mn.mockNodes["window['eval']('var i;');"];
-    test.assertEqual(true, check.invokesMethodBracketSuffix(n));
-    testCheckNontrivial(test, n);
-    test.done();
+    assert.equal(true, check.invokesMethodBracketSuffix(n));
+    testCheckNontrivial(assert, n);
+};
 
-}
-
-exports.testInvokesMethodBracketSuffixArray = function (test) {
+exports.testInvokesMethodBracketSuffixArray = function(assert) {
     // n1 corresponds to array[num] = 'some text';
     var n = mn.mockNodes["array[num] = 'some text';"];
-    test.assertNotEqual(true, check.invokesMethodBracketSuffix(n));
-    test.done();
-}
+    assert.notEqual(true, check.invokesMethodBracketSuffix(n));
+};
 
-exports.testCreatesXhrObject = function (test) {
+exports.testCreatesXhrObject = function(assert) {
     // n1 corresponds to identifier "XMLHttpRequest"
-    var n = mn.mockNodes['XMLHttpRequest'];
-    test.assertEqual(true, check.createsXhrObject(n));
-    testCheckNontrivial(test, n);
-    test.done();
+    var n = mn.mockNodes.XMLHttpRequest;
+    assert.equal(true, check.createsXhrObject(n));
+    testCheckNontrivial(assert, n);
 };
 
-exports.testCreatesXhrObject_MS = function (test) {
+exports.testCreatesXhrObject_MS = function (assert) {
     // n1 corresponds to identifier "ActiveXObject"
-    var n = mn.mockNodes['ActiveXObject'];
-    test.assertEqual(true, check.createsXhrObject(n));
-    test.done();
+    var n = mn.mockNodes.ActiveXObject;
+    assert.equal(true, check.createsXhrObject(n));
 };
 
-exports.testInvokesXhrOpen = function (test) {
+exports.testInvokesXhrOpen = function (assert) {
     // n1 corresponds to: 
     // "oReq.open("GET", "http://localhost/test.xml", true);"
-    var n = mn.mockNodes["oReq.open\('GET', 'http://localhost/test.xml', true;\)"];
-    test.assertEqual(true, check.invokesXhrOpen(n));
-    testCheckNontrivial(test, n);
-    test.done();
-}
-
-exports.testInvokesMethodOpenNotXhr = function (test) {
-    // n1 corresponds to: 
-    // "oReq.open("a random string");"
-    var n = mn.mockNodes["oReq.open\('a random string'\);"];
-    test.assertNotEqual('global', check.invokesXhrOpen(n));
-    test.done();
+    var n = mn.mockNodes["oReq.open('GET', 'http://localhost/test.xml', true;)"];
+    assert.equal(true, check.invokesXhrOpen(n));
+    testCheckNontrivial(assert, n);
 };
 
-exports.testCreatesScriptElement = function (test) {
+exports.testInvokesMethodOpenNotXhr = function (assert) {
+    // n1 corresponds to: 
+    // "oReq.open("a random string");"
+    var n = mn.mockNodes["oReq.open('a random string');"];
+    assert.notEqual('global', check.invokesXhrOpen(n));
+};
+
+exports.testCreatesScriptElement = function (assert) {
     // n1 corresponds to:
     // "document.createElement('script');"
     var n = mn.mockNodes["document.createElement('script');"];
-    test.assertEqual(true, check.createsScriptElement(n));
-    testCheckNontrivial(test, n);
-    test.done();
+    assert.equal(true, check.createsScriptElement(n));
+    testCheckNontrivial(assert, n);
 };
 
-exports.testScriptWrittenAsHtmlString = function (test) {
+exports.testScriptWrittenAsHtmlString = function(assert) {
     // string written corresponds to: 
     //<script src=\"evil-js.js\"type=\"text/javascript\></script>
     // and written with document.write();
-    var n = mn.mockNodes['document.write\("script src=\"evil-js.js\"type=\"text/javascript\></script>"\)'];
-    test.assertEqual(true, check.writesScriptAsHtmlString(n));
-    testCheckNontrivial(test, n);
-    test.done();
+    var n = mn.mockNodes[
+        'document.write("script src=\"evil-js.js\"type=\"text/javascript></script>")'];
+    assert.equal(true, check.writesScriptAsHtmlString(n));
+    testCheckNontrivial(assert, n);
 };
 
-exports.testScriptWrittenAsStringConcat = function (test) {
+exports.testScriptWrittenAsStringConcat = function(assert) {
     // string written corresponds to: 
     // document.write('a ' + ' text');
     // since we are not currently analyzing such construct
     // we are flagging it as nontrivial.
-    var n = mn.mockNodes["document.write\('a ' + ' text'\);"];
-    test.assertEqual(true, check.writesScriptAsHtmlString(n));
-    testCheckNontrivial(test, n);
-    test.done();
+    var n = mn.mockNodes["document.write('a ' + ' text');"];
+    assert.equal(true, check.writesScriptAsHtmlString(n));
+    testCheckNontrivial(assert, n);
 };
 
-exports.testWriteNonscriptHtmlString = function (test) {
+exports.testWriteNonscriptHtmlString = function(assert) {
 // corresponds to: document.write('<h1>some text</h1>');
-    var n = mn.mockNodes["document.write\('<h1>some text</h1>'\)"];
-    test.assertEqual(false, check.writesScriptAsHtmlString(n));
-    test.done();  
+    var n = mn.mockNodes["document.write('<h1>some text</h1>')"];
+    assert.equal(false, check.writesScriptAsHtmlString(n));
 };
 
 /*exports.testSetsInnerHTMLProperty = function (test) {
@@ -188,4 +175,6 @@ exports.testCheckNonTrivialWithFuncDefAndHtmlLoadsExternalScriptsAndIsLoadedExte
     // making sure we have a correct (as expected) tree
     test.assertEqual('local', subcheck.checkNontrivial(n));
     test.done();
-};*/
\ No newline at end of file
+};*/
+
+require('sdk/test').run(exports);
